# <img align="top" src="https://raw.githubusercontent.com/ReactionMechanismGenerator/RMG-Py/master/documentation/source/_static/rmg-logo-small.png"> Reaction Mechanism Generator (RMG)


## Description
This repository contains the Python version of **Reaction Mechanism Generator (RMG)**,
a tool for automatically generating chemical reaction
mechanisms for modeling reaction systems including pyrolysis, combustion,
atmospheric science, and more.

It also includes **CanTherm**, the package for calculating thermodynamics, high-pressure-limit
rate coefficients, and pressure dependent rate coefficients from quantum chemical calculations.
CanTherm is compatible with a variety of ab initio quantum chemistry software programs, including but not limited to
Gaussian, MOPAC, QChem, and MOLPRO.

## Source Code Repository
- [RMG Github Repository](https://github.com/ReactionMechanismGenerator/RMG-Py): contains the latest source code for RMG
- [RMG-database Github Repository](https://github.com/ReactionMechanismGenerator/RMG-database): contains source code for the latest version of the database

## Latest Stable Release
**RMG v2.1.4**
[![Anaconda-Server Badge](https://anaconda.org/rmg/rmg/badges/version.svg)](https://anaconda.org/rmg/rmg)

View the [Release Notes](http://reactionmechanismgenerator.github.io/RMG-Py/users/rmg/releaseNotes.html).

## How to Install
View the [Download and Install](http://reactionmechanismgenerator.github.io/RMG-Py/users/rmg/installation/index.html) page.

## Documentation
- [RMG Documentation](http://ReactionMechanismGenerator.github.io/RMG-Py/) ([PDF version](https://github.com/ReactionMechanismGenerator/RMG-Py/raw/master/documentation/RMG-Py_and_CanTherm_Documentation.pdf))
- [CanTherm Documentation](http://ReactionMechanismGenerator.github.io/RMG-Py/users/cantherm/) ([PDF version](https://github.com/ReactionMechanismGenerator/RMG-Py/raw/master/documentation/RMG-Py_and_CanTherm_Documentation.pdf))
- [RMG API Reference](http://reactionmechanismgenerator.github.io/RMG-Py/reference/index.html) ([PDF version](https://github.com/ReactionMechanismGenerator/RMG-Py/raw/master/documentation/RMG-Py_API_Reference.pdf))

Alternatively, PDF versions of all the documentation can also be found in the `documentation` folder of the source code.  

## Credits

- [Professor William H. Green's research group](http://cheme.scripts.mit.edu/green-group/) at the 
[Massachusetts Institute of Technology](http://web.mit.edu/) 
- [Professor Richard H. West's research group](http://www.northeastern.edu/comocheng/) at 
[Northeastern University](http://www.northeastern.edu/). 

## How to Give Feedback

Please post any issues you may have to the [issues page](https://github.com/ReactionMechanismGenerator/RMG-Py/issues/)
or drop in to the [chat room](https://gitter.im/ReactionMechanismGenerator/RMG-Py) or email [rmg_dev@mit.edu](mailto:rmg_dev@mit.edu) if you have questions.  
[![Join the chat at https://gitter.im/ReactionMechanismGenerator/RMG-Py](https://badges.gitter.im/ReactionMechanismGenerator/RMG-Py.svg)](https://gitter.im/ReactionMechanismGenerator/RMG-Py?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)

## Useful Links

- [Interactive Website](http://rmg.mit.edu): Visit this site to visualize RMG-generated models, view the databases, and 
perform thermodynamics and kinetics searches
- [Wiki](https://github.com/ReactionMechanismGenerator/RMG-Py/wiki): a wiki for developer notes
- [Issues Page](https://github.com/ReactionMechanismGenerator/RMG-Py/issues/): view current issues and feature requests


## Continuous Integration

We have a continuous integration build test suite 
which you can access at https://travis-ci.org/ReactionMechanismGenerator/RMG-Py
The current build status is
[![Build Status](https://travis-ci.org/ReactionMechanismGenerator/RMG-Py.svg?branch=master)](https://travis-ci.org/ReactionMechanismGenerator/RMG-Py)
